@@ -1,8 +1,8 @@
 /*
   +----------------------------------------------------------------------+
-  | PHP Version 5                                                        |
+  | PHP Version 7                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 1997-2014 The PHP Group                                |
+  | Copyright (c) 1997-2018 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -16,8 +16,6 @@
   |          Andrey Hristov <andrey@php.net>                             |
   |          Ulf Wendel <uw@php.net>                                     |
   +----------------------------------------------------------------------+
-
-  $Id$
 */
 
 #ifdef HAVE_CONFIG_H
@@ -43,23 +41,24 @@
 #define MYSQLI_ZEND_ARG_OBJ_INFO_STMT() ZEND_ARG_INFO(0, stmt)
 #endif
 
-ZEND_BEGIN_ARG_INFO(arginfo_mysqli_stmt_bind_result, 1)
+ZEND_BEGIN_ARG_INFO(arginfo_mysqli_stmt_bind_result, 0)
 	MYSQLI_ZEND_ARG_OBJ_INFO_STMT()
+	ZEND_ARG_VARIADIC_INFO(1, vars)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO(arginfo_mysqli_stmt_bind_param, 1)
+ZEND_BEGIN_ARG_INFO(arginfo_mysqli_stmt_bind_param, 0)
 	MYSQLI_ZEND_ARG_OBJ_INFO_STMT()
 	ZEND_ARG_INFO(0, types)
+	ZEND_ARG_VARIADIC_INFO(1, vars)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO(arginfo_class_mysqli_stmt_bind_result, 1)
+ZEND_BEGIN_ARG_INFO(arginfo_class_mysqli_stmt_bind_result, 0)
+	ZEND_ARG_VARIADIC_INFO(1, vars)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO(arginfo_class_mysqli_stmt_bind_param, 1)
+ZEND_BEGIN_ARG_INFO(arginfo_class_mysqli_stmt_bind_param, 0)
 	ZEND_ARG_INFO(0, types)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO(all_args_force_by_ref, 1)
+	ZEND_ARG_VARIADIC_INFO(1, vars)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_poll, 0, 0, 4)
@@ -86,6 +85,67 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_autocommit, 0, 0, 1)
 	ZEND_ARG_INFO(0, mode)
 ZEND_END_ARG_INFO()
 
+ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_begin_transaction, 0, 0, 1)
+	MYSQLI_ZEND_ARG_OBJ_INFO_LINK()
+	ZEND_ARG_INFO(0, flags)
+	ZEND_ARG_INFO(0, name)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_begin_transaction, 0, 0, 0)
+	ZEND_ARG_INFO(0, flags)
+	ZEND_ARG_INFO(0, name)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_savepoint, 0, 0, 2)
+	MYSQLI_ZEND_ARG_OBJ_INFO_LINK()
+	ZEND_ARG_INFO(0, name)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_savepoint, 0, 0, 1)
+	ZEND_ARG_INFO(0, name)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_release_savepoint, 0, 0, 2)
+	MYSQLI_ZEND_ARG_OBJ_INFO_LINK()
+	ZEND_ARG_INFO(0, name)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_release_savepoint, 0, 0, 1)
+	ZEND_ARG_INFO(0, name)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_commit, 0, 0, 1)
+	MYSQLI_ZEND_ARG_OBJ_INFO_LINK()
+	ZEND_ARG_INFO(0, flags)
+	ZEND_ARG_INFO(0, name)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_commit, 0, 0, 0)
+	ZEND_ARG_INFO(0, flags)
+	ZEND_ARG_INFO(0, name)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_rollback, 0, 0, 1)
+	MYSQLI_ZEND_ARG_OBJ_INFO_LINK()
+	ZEND_ARG_INFO(0, flags)
+	ZEND_ARG_INFO(0, name)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_rollback, 0, 0, 0)
+	ZEND_ARG_INFO(0, flags)
+	ZEND_ARG_INFO(0, name)
+ZEND_END_ARG_INFO()
+
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_store_result, 0, 0, 1)
+	MYSQLI_ZEND_ARG_OBJ_INFO_LINK()
+	ZEND_ARG_INFO(0, flags)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_class_store_result, 0, 0, 0)
+	ZEND_ARG_INFO(0, flags)
+ZEND_END_ARG_INFO()
+
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_change_user, 0, 0, 4)
 	MYSQLI_ZEND_ARG_OBJ_INFO_LINK()
@@ -177,18 +237,14 @@ ZEND_END_ARG_INFO()
 
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_fetch_object, 0, 0, 1)
-#if PHP_VERSION_ID > 50399
 	MYSQLI_ZEND_ARG_OBJ_INFO_RESULT()
 	ZEND_ARG_INFO(0, class_name)
 	ZEND_ARG_ARRAY_INFO(0, params, 0)
-#endif
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_fetch_object, 0, 0, 0)
-#if PHP_VERSION_ID > 50399
 	ZEND_ARG_INFO(0, class_name)
 	ZEND_ARG_ARRAY_INFO(0, params, 0)
-#endif
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_kill, 0, 0, 2)
@@ -200,19 +256,20 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_kill, 0, 0, 1)
 	ZEND_ARG_INFO(0, connection_id)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_set_local_infile_handler, 0, 0, 2)
-	MYSQLI_ZEND_ARG_OBJ_INFO_LINK()
-	ZEND_ARG_INFO(0, read_callback)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_set_local_infile_handler, 0, 0, 1)
-	MYSQLI_ZEND_ARG_OBJ_INFO_LINK()
-	ZEND_ARG_INFO(0, read_callback)
-ZEND_END_ARG_INFO()
-
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_query, 0, 0, 2)
 	MYSQLI_ZEND_ARG_OBJ_INFO_LINK()
 	ZEND_ARG_INFO(0, query)
+	ZEND_ARG_INFO(0, resultmode)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_multi_query, 0, 0, 1)
+	MYSQLI_ZEND_ARG_OBJ_INFO_LINK()
+	ZEND_ARG_INFO(0, query)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_real_query, 0, 0, 1)
+	MYSQLI_ZEND_ARG_OBJ_INFO_LINK()
+	ZEND_ARG_INFO(0, query)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_prepare, 0, 0, 2)
@@ -227,6 +284,19 @@ ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_query, 0, 0, 1)
 	ZEND_ARG_INFO(0, query)
+	ZEND_ARG_INFO(0, resultmode)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_prepare, 0, 0, 1)
+	ZEND_ARG_INFO(0, query)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_multi_query, 0, 0, 1)
+	ZEND_ARG_INFO(0, query)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_real_query, 0, 0, 1)
+	ZEND_ARG_INFO(0, query)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_options, 0, 0, 3)
@@ -328,6 +398,9 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_class_mysqli_refresh, 0, 0, 1)
 	ZEND_ARG_INFO(0, options)
 ZEND_END_ARG_INFO()
 
+ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqli_no_options, 0, 0, 0)
+ZEND_END_ARG_INFO()
+
 
 /* {{{ mysqli_functions[]
  *
@@ -336,10 +409,11 @@ ZEND_END_ARG_INFO()
 const zend_function_entry mysqli_functions[] = {
 	PHP_FE(mysqli_affected_rows,						arginfo_mysqli_only_link)
 	PHP_FE(mysqli_autocommit,							arginfo_mysqli_autocommit)
+	PHP_FE(mysqli_begin_transaction,					arginfo_mysqli_begin_transaction)
 	PHP_FE(mysqli_change_user,							arginfo_mysqli_change_user)
 	PHP_FE(mysqli_character_set_name,					arginfo_mysqli_only_link)
 	PHP_FE(mysqli_close,								arginfo_mysqli_only_link)
-	PHP_FE(mysqli_commit,								arginfo_mysqli_only_link)
+	PHP_FE(mysqli_commit,								arginfo_mysqli_commit)
 	PHP_FE(mysqli_connect, 								arginfo_mysqli_connect)
 	PHP_FE(mysqli_connect_errno,						arginfo_mysqli_no_params)
 	PHP_FE(mysqli_connect_error,						arginfo_mysqli_no_params)
@@ -360,7 +434,7 @@ const zend_function_entry mysqli_functions[] = {
 	PHP_FE(mysqli_fetch_field_direct,					arginfo_mysqli_result_and_fieldnr)
 	PHP_FE(mysqli_fetch_lengths,						arginfo_mysqli_only_result)
 #ifdef MYSQLI_USE_MYSQLND
-	PHP_FE(mysqli_fetch_all,							arginfo_mysqli_only_result)
+	PHP_FE(mysqli_fetch_all,							arginfo_mysqli_fetch_array)
 #endif
 	PHP_FE(mysqli_fetch_array,							arginfo_mysqli_fetch_array)
 	PHP_FE(mysqli_fetch_assoc,							arginfo_mysqli_only_result)
@@ -377,8 +451,9 @@ const zend_function_entry mysqli_functions[] = {
 #ifdef HAVE_MYSQLI_GET_CHARSET
 	PHP_FE(mysqli_get_charset,							arginfo_mysqli_only_link)
 #endif
-	PHP_FE(mysqli_get_client_info,						arginfo_mysqli_only_link)
+	PHP_FE(mysqli_get_client_info,						arginfo_mysqli_no_options)
 	PHP_FE(mysqli_get_client_version,					arginfo_mysqli_only_link)
+	PHP_FE(mysqli_get_links_stats,						arginfo_mysqli_no_options)
 	PHP_FE(mysqli_get_host_info,						arginfo_mysqli_only_link)
 	PHP_FE(mysqli_get_proto_info,						arginfo_mysqli_only_link)
 	PHP_FE(mysqli_get_server_info,						arginfo_mysqli_only_link)
@@ -388,12 +463,8 @@ const zend_function_entry mysqli_functions[] = {
 	PHP_FE(mysqli_info,									arginfo_mysqli_only_link)
 	PHP_FE(mysqli_insert_id,							arginfo_mysqli_only_link)
 	PHP_FE(mysqli_kill,									arginfo_mysqli_kill)
-#if !defined(MYSQLI_USE_MYSQLND)
-	PHP_FE(mysqli_set_local_infile_default,				arginfo_mysqli_only_link)
-	PHP_FE(mysqli_set_local_infile_handler,				arginfo_mysqli_set_local_infile_handler)
-#endif
 	PHP_FE(mysqli_more_results,							arginfo_mysqli_only_link)
-	PHP_FE(mysqli_multi_query, 							arginfo_mysqli_query)
+	PHP_FE(mysqli_multi_query, 							arginfo_mysqli_multi_query)
 	PHP_FE(mysqli_next_result,							arginfo_mysqli_only_link)
 	PHP_FE(mysqli_num_fields,							arginfo_mysqli_only_result)
 	PHP_FE(mysqli_num_rows,								arginfo_mysqli_only_result)
@@ -407,11 +478,13 @@ const zend_function_entry mysqli_functions[] = {
 	PHP_FE(mysqli_query,								arginfo_mysqli_query)
 	PHP_FE(mysqli_real_connect,							arginfo_mysqli_real_connect)
 	PHP_FE(mysqli_real_escape_string,					arginfo_mysqli_real_escape_string)
-	PHP_FE(mysqli_real_query,							arginfo_mysqli_query)
+	PHP_FE(mysqli_real_query,							arginfo_mysqli_real_query)
 #if defined(MYSQLI_USE_MYSQLND)
 	PHP_FE(mysqli_reap_async_query,						arginfo_mysqli_only_link)
 #endif
-	PHP_FE(mysqli_rollback,								arginfo_mysqli_only_link)
+	PHP_FE(mysqli_release_savepoint,					arginfo_mysqli_release_savepoint)
+	PHP_FE(mysqli_rollback,								arginfo_mysqli_rollback)
+	PHP_FE(mysqli_savepoint,							arginfo_mysqli_savepoint)
 	PHP_FE(mysqli_select_db,							arginfo_mysqli_select_db)
 #ifdef HAVE_MYSQLI_SET_CHARSET
 	PHP_FE(mysqli_set_charset,							arginfo_mysqli_set_charset)
@@ -450,7 +523,7 @@ const zend_function_entry mysqli_functions[] = {
 	PHP_FE(mysqli_sqlstate,   							arginfo_mysqli_only_link)
 	PHP_FE(mysqli_ssl_set,								arginfo_mysqli_ssl_set)
 	PHP_FE(mysqli_stat,									arginfo_mysqli_only_link)
-	PHP_FE(mysqli_store_result,							arginfo_mysqli_only_link)
+	PHP_FE(mysqli_store_result,							arginfo_mysqli_store_result)
 	PHP_FE(mysqli_thread_id,							arginfo_mysqli_only_link)
 	PHP_FE(mysqli_thread_safe,							arginfo_mysqli_no_params)
 	PHP_FE(mysqli_use_result,							arginfo_mysqli_only_link)
@@ -472,10 +545,11 @@ const zend_function_entry mysqli_functions[] = {
  */
 const zend_function_entry mysqli_link_methods[] = {
 	PHP_FALIAS(autocommit, mysqli_autocommit, arginfo_class_mysqli_autocommit)
+	PHP_FALIAS(begin_transaction, mysqli_begin_transaction, arginfo_class_mysqli_begin_transaction)
 	PHP_FALIAS(change_user,mysqli_change_user, arginfo_class_mysqli_change_user)
 	PHP_FALIAS(character_set_name, mysqli_character_set_name, arginfo_mysqli_no_params)
 	PHP_FALIAS(close, mysqli_close, arginfo_mysqli_no_params)
-	PHP_FALIAS(commit, mysqli_commit, arginfo_mysqli_no_params)
+	PHP_FALIAS(commit, mysqli_commit, arginfo_class_mysqli_commit)
 	PHP_FALIAS(connect, mysqli_connect, arginfo_mysqli_connect)
 	PHP_FALIAS(dump_debug_info, mysqli_dump_debug_info, arginfo_mysqli_no_params)
 	PHP_FALIAS(debug, mysqli_debug, arginfo_mysqli_debug)
@@ -488,14 +562,10 @@ const zend_function_entry mysqli_link_methods[] = {
 #endif
 	PHP_FALIAS(get_server_info, mysqli_get_server_info, arginfo_mysqli_no_params)
 	PHP_FALIAS(get_warnings, mysqli_get_warnings, arginfo_mysqli_no_params)
-	PHP_FALIAS(init,mysqli_init, arginfo_mysqli_no_params)
+	PHP_FALIAS(init,mysqli_init_method, arginfo_mysqli_no_params)
 	PHP_FALIAS(kill,mysqli_kill, arginfo_class_mysqli_kill)
-#if !defined(MYSQLI_USE_MYSQLND)
-	PHP_FALIAS(set_local_infile_default, mysqli_set_local_infile_default, arginfo_mysqli_no_params)
-	PHP_FALIAS(set_local_infile_handler, mysqli_set_local_infile_handler, arginfo_class_mysqli_set_local_infile_handler)
-#endif
-	PHP_FALIAS(multi_query, mysqli_multi_query, arginfo_class_mysqli_query)
-	PHP_FALIAS(mysqli, mysqli_link_construct, arginfo_mysqli_connect)
+	PHP_FALIAS(multi_query, mysqli_multi_query, arginfo_class_mysqli_multi_query)
+	PHP_FALIAS(__construct, mysqli_link_construct, arginfo_mysqli_connect)
 	PHP_FALIAS(more_results, mysqli_more_results, arginfo_mysqli_no_params)
 	PHP_FALIAS(next_result, mysqli_next_result, arginfo_mysqli_no_params)
 	PHP_FALIAS(options, mysqli_options, arginfo_class_mysqli_options)
@@ -503,7 +573,7 @@ const zend_function_entry mysqli_link_methods[] = {
 #if defined(MYSQLI_USE_MYSQLND)
 	ZEND_FENTRY(poll, ZEND_FN(mysqli_poll), arginfo_mysqli_poll, ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
 #endif
-	PHP_FALIAS(prepare, mysqli_prepare, arginfo_class_mysqli_query)
+	PHP_FALIAS(prepare, mysqli_prepare, arginfo_class_mysqli_prepare)
 	PHP_FALIAS(query, mysqli_query, arginfo_class_mysqli_query)
 	PHP_FALIAS(real_connect, mysqli_real_connect, arginfo_class_mysqli_real_connect)
 	PHP_FALIAS(real_escape_string, mysqli_real_escape_string, arginfo_class_mysqli_real_escape_string)
@@ -511,8 +581,10 @@ const zend_function_entry mysqli_link_methods[] = {
 	PHP_FALIAS(reap_async_query, mysqli_reap_async_query, arginfo_mysqli_no_params)
 #endif
 	PHP_FALIAS(escape_string, mysqli_real_escape_string, arginfo_class_mysqli_real_escape_string)
-	PHP_FALIAS(real_query, mysqli_real_query, arginfo_class_mysqli_query)
-	PHP_FALIAS(rollback,mysqli_rollback, arginfo_mysqli_no_params)
+	PHP_FALIAS(real_query, mysqli_real_query, arginfo_class_mysqli_real_query)
+	PHP_FALIAS(release_savepoint, mysqli_release_savepoint, arginfo_class_mysqli_release_savepoint)
+	PHP_FALIAS(rollback, mysqli_rollback, arginfo_class_mysqli_rollback)
+	PHP_FALIAS(savepoint, mysqli_savepoint, arginfo_class_mysqli_savepoint)
 	PHP_FALIAS(select_db,mysqli_select_db, arginfo_class_mysqli_select_db)
 #ifdef HAVE_MYSQLI_SET_CHARSET
 	PHP_FALIAS(set_charset, mysqli_set_charset, arginfo_class_mysqli_set_charset)
@@ -521,11 +593,11 @@ const zend_function_entry mysqli_link_methods[] = {
 	PHP_FALIAS(ssl_set, mysqli_ssl_set, arginfo_class_mysqli_ssl_set)
 	PHP_FALIAS(stat, mysqli_stat, arginfo_mysqli_no_params)
 	PHP_FALIAS(stmt_init, mysqli_stmt_init, arginfo_mysqli_no_params)
-	PHP_FALIAS(store_result, mysqli_store_result, arginfo_mysqli_no_params)
+	PHP_FALIAS(store_result, mysqli_store_result, arginfo_class_store_result)
 	PHP_FALIAS(thread_safe, mysqli_thread_safe, arginfo_mysqli_no_params)
 	PHP_FALIAS(use_result, mysqli_use_result, arginfo_mysqli_no_params)
 	PHP_FALIAS(refresh,mysqli_refresh, arginfo_class_mysqli_refresh)
-	{NULL, NULL, NULL}
+	PHP_FE_END
 };
 /* }}} */
 
@@ -542,7 +614,7 @@ const zend_function_entry mysqli_result_methods[] = {
 	PHP_FALIAS(fetch_fields, mysqli_fetch_fields, arginfo_mysqli_no_params)
 	PHP_FALIAS(fetch_field_direct, mysqli_fetch_field_direct, arginfo_class_mysqli_result_and_fieldnr)
 #if defined(MYSQLI_USE_MYSQLND)
-	PHP_FALIAS(fetch_all, mysqli_fetch_all, arginfo_mysqli_no_params)
+	PHP_FALIAS(fetch_all, mysqli_fetch_all, arginfo_class_mysqli_fetch_array)
 #endif
 	PHP_FALIAS(fetch_array, mysqli_fetch_array, arginfo_class_mysqli_fetch_array)
 	PHP_FALIAS(fetch_assoc, mysqli_fetch_assoc, arginfo_mysqli_no_params)
@@ -550,7 +622,7 @@ const zend_function_entry mysqli_result_methods[] = {
 	PHP_FALIAS(fetch_row, mysqli_fetch_row, arginfo_mysqli_no_params)
 	PHP_FALIAS(field_seek, mysqli_field_seek, arginfo_class_mysqli_result_and_fieldnr)
 	PHP_FALIAS(free_result, mysqli_free_result, arginfo_mysqli_no_params)
-	{NULL, NULL, NULL}
+	PHP_FE_END
 };
 /* }}} */
 
@@ -578,12 +650,12 @@ const zend_function_entry mysqli_stmt_methods[] = {
 	PHP_FALIAS(send_long_data, mysqli_stmt_send_long_data, arginfo_class_mysqli_stmt_send_long_data)
 	PHP_FALIAS(free_result, mysqli_stmt_free_result, arginfo_mysqli_no_params)
 	PHP_FALIAS(reset, mysqli_stmt_reset, arginfo_mysqli_no_params)
-	PHP_FALIAS(prepare, mysqli_stmt_prepare, arginfo_class_mysqli_query)
+	PHP_FALIAS(prepare, mysqli_stmt_prepare, arginfo_class_mysqli_prepare)
 	PHP_FALIAS(store_result, mysqli_stmt_store_result, arginfo_mysqli_no_params)
 #if defined(MYSQLI_USE_MYSQLND)
 	PHP_FALIAS(get_result, mysqli_stmt_get_result, arginfo_mysqli_no_params)
 #endif
-	{NULL, NULL, NULL}
+	PHP_FE_END
 };
 /* }}} */
 
